#!/usr/bin/env raku

use Terminal::ANSI;
use thelper;

clear-screen;
home;
set-scroll-region(3,7);
print-at 2,1, "---------";
print-at 8,1, "---------";
move-to 3,1;
for 1..20 {
  print "\n" unless $_ == 1;
  print "line $_";
}
reset-scroll-region;

await-test;
