#!/usr/bin/env raku

use Terminal::ANSI;

clear-screen;
print-at 1,1, '1,1';
cursor-right(5);
print 'right 5';
cursor-down(2);
print 'down 2';
cursor-down(10);
cursor-left(10);
print 'down 10, left 10';
for 1..4 {
  cursor-down(1);
  cursor-left(17);
  print 'down 1, left 17';
}
print "\n";
print "\n";
